==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Widgets/FirstStart/ts/FirstStart_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>FirstStart</name>
    <message>
        <location filename="../FirstStart.js" line="+35"/>
        <source>%1 First Start</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Pierwszy start</translation>
    </message>
    <message>
        <location line="+185"/>
        <source>Black</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Czarny / Biały
Bardzo gruby</translatorcomment>
        <translation type="unfinished">Bardzo gruby</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>White</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Czarny / Biały
Biały</translatorcomment>
        <translation type="unfinished">Biały</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Language:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Język interfejsu graficznego:
Język komend:
Język poleceń:</translatorcomment>
        <translation type="unfinished">Język:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Welcome to %1</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Witamy</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Please choose the settings used for new drawings. All these settings can be changed later in the Preference Dialog.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Proszę wybrać ustawienia wykorzystywane dla nowych rysunków. Wszystkie te ustawienia można zmienić później w oknie dialogowym Preferencje.</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Unit:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Jednostka domyślna:
&amp;Główna jednostka rysowania:</translatorcomment>
        <translation type="unfinished">Jednostka:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Default Paper Size:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Domyślny rozmiar papieru:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal Point:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Przecinku:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Background Color:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Kolor tła:</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Widgets/FirstStart/ts/FirstStart_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>FirstStart</name>
    <message>
        <location filename="../FirstStart.js" line="+35"/>
        <location line="+216"/>
        <source>%1 First Start</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Pierwszy start</translation>
    </message>
    <message>
        <location line="-5"/>
        <source>Black</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Czarny / Biały
Bardzo gruby</translatorcomment>
        <translation type="unfinished">Bardzo gruby</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>White</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Czarny / Biały
Biały</translatorcomment>
        <translation type="unfinished">Biały</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Language:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Język interfejsu graficznego:
Język komend:
Język poleceń:</translatorcomment>
        <translation type="unfinished">Język:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Welcome to %1</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Witamy</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Please choose the settings used for new drawings. All these settings can be changed later in the Preference Dialog.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Proszę wybrać ustawienia wykorzystywane dla nowych rysunków. Wszystkie te ustawienia można zmienić później w oknie dialogowym Preferencje.</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Unit:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Jednostka domyślna:
&amp;Główna jednostka rysowania:</translatorcomment>
        <translation type="unfinished">Jednostka:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Default Paper Size:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Domyślny rozmiar papieru:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal Point:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Przecinku:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Background Color:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Kolor tła:</translation>
    </message>
</context>
</TS>
